@@ -1,13 +1,12 @@
 import copy
+import json
 
+from django.db import models
 from django.forms.models import ModelChoiceIterator
 from django.http import HttpResponse
 from django.utils.encoding import force_unicode
-from django.utils.simplejson import simplejson
 
-from django.db import models
-
-from .fields import ForeignKey
+from .fields import ManyToManyField
 
 
 class ViewException(Exception):
@@ -24,7 +23,7 @@ class JsonResponse(HttpResponse):
 
     def __init__(self, content='', callback=None, mimetype="application/json", *args, **kwargs):
         if not isinstance(content, basestring):
-            content = simplejson.dumps(content)
+            content = json.dumps(content)
         if callback is not None:
             self.callback = callback
         if self.callback is not None:
@@ -117,10 +116,9 @@ class Select2View(object):
         except InvalidParameter, e:
             return self.get_response({'error': unicode(e)}, status=500)
 
-        queryset = copy.deepcopy(field.queryset)
-        queryset = queryset.filter(**{
+        queryset = field.queryset.filter(**{
             (u'%s__in' % field.rel.get_related_field().name): pks,
-        })
+        }).distinct()
         pk_ordering = dict([(force_unicode(pk), i) for i, pk in enumerate(pks)])
 
         data = self.get_data(queryset)
@@ -131,8 +129,16 @@ class Select2View(object):
             return pk_ordering[pk]
         data['results'] = sorted(data['results'], key=results_sort_callback)
 
-        if isinstance(field, ForeignKey) and len(data['results']) == 1:
-            data['results'] = data['results'][0]
+        if len(data['results']) == 1:
+            is_multiple = isinstance(field, ManyToManyField)
+            try:
+                multiple_param = int(self.request.GET.get('multiple'))
+            except (TypeError, ValueError):
+                pass
+            else:
+                is_multiple = (multiple_param == 1)
+            if not is_multiple:
+                data['results'] = data['results'][0]
 
         return self.get_response(data)
 
